KeyRateLimit

Struct KeyRateLimit 

pub struct KeyRateLimit { /* private fields */ }
Rate limit state for a single key

Implementations

Source

impl KeyRateLimit

pub fn new() -> Self

Create a new rate limit state

pub fn check_and_increment( &mut self, config: &RateLimitConfig, ) -> RateLimitResult

Check the rate limit and increment counters if allowed

Returns the result of the rate limit check.

pub fn is_expired(&self) -> bool

Check if this rate limit state has expired (inactive for over an hour)

pub fn minute_count(&self) -> u32

Get the current minute count

pub fn hour_count(&self) -> u32

Get the current hour count